@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.14";
+our $VERSION = "2.15";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -17,13 +17,24 @@ use Text::VisualWidth::PP 'vwidth';
 use Exporter 'import';
 our %EXPORT_TAGS = (
     constants => [ qw(
-		   &LINEBREAK_NONE
-		   &LINEBREAK_ALL
-		   &LINEBREAK_RUNIN
-		   &LINEBREAK_RUNOUT
-		   ) ] );
+	&LINEBREAK_NONE
+	&LINEBREAK_ALL
+	&LINEBREAK_RUNIN
+	&LINEBREAK_RUNOUT
+	) ],
+    regex => [ qw(
+	$reset_re
+	$color_re
+	$erase_re
+	$csi_re
+	$osc_re
+	) ],
+    );
+
 our @EXPORT_OK = ( qw(&ansi_fold),
-		   @{$EXPORT_TAGS{constants}} );
+		   @{$EXPORT_TAGS{constants}},
+		   @{$EXPORT_TAGS{regex}},
+    );
 
 sub ansi_fold {
     my($text, $width, @option) = @_;
@@ -362,6 +373,9 @@ sub fold {
 	}
     }
 
+    ##
+    ## --boundary=word
+    ##
     if ($word_char_re
 	and my($tail) = /\A(${word_char_re}+)/
 	and $folded =~ m{
@@ -376,7 +390,9 @@ sub fold {
 	## provided for the word in the next turn.
 	my($s, $e) = ($-[3], $+[3]);
 	my $l = $e - $s;
-	if ($room + $l < $width and $l + length($tail) <= $width) {
+	## prefix length
+	my $p = $opt->{prefix} eq '' ? 0 : vwidth $opt->{prefix};
+	if ($room + $l < $width - $p and $l + length($tail) <= $width - $p) {
 	    $_ = substr($folded, $s, $l, '') . pop_reset() . $_;
 	    $room += $l;
 	}
@@ -534,7 +550,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.14
+Version 2.15
 
 =head1 SYNOPSIS
 
@@ -586,9 +602,9 @@ of visual columns you want to cut off the text.
 It returns a pair of strings; first one is folded text, and second is
 the rest.
 
-Additional third result is the visual width of folded text.  You may
-want to know how many columns returned string takes for further
-processing.
+Additional third result is the visual width of the folded text.  It is
+not always same as given width, and you may want to know how many
+columns returned string takes for further processing.
 
 Negative width value is taken as unlimited.  So the string is never
 folded, but you can use this to expand tabs and to get visual string
@@ -702,11 +718,11 @@ Specify folding width.  Negative value means all the rest.
 Array reference can be specified but works only with B<chops> method,
 and retunrs empty string for zero width.
 
-=item B<boundary> => I<word> or I<space>
+=item B<boundary> => C<word> or C<space>
 
-Option B<boundary> takes I<word> and I<space> as a valid value.  These
+Option B<boundary> takes C<word> and C<space> as a valid value.  These
 prohibit to fold a line in the middle of ASCII/Latin sequence.  Value
-I<word> means a sequence of alpha-numeric characters, and I<space>
+C<word> means a sequence of alpha-numeric characters, and C<space>
 means simply non-space printables.
 
 This operation takes place only when enough space will be provided to
@@ -743,13 +759,13 @@ B<chops> interface.
 If the value is reference to subroutine, its result is used as a
 prefix string.
 
-=item B<ambiguous> => "narrow" or "wide"
+=item B<ambiguous> => C<narrow> or C<wide>
 
 Tells how to treat Unicode East Asian ambiguous characters.  Default
-is "narrow" which means single column.  Set "wide" to tell the module
-to treat them as wide character.
+is C<narrow> which means single column.  Set C<wide> to tell the
+module to treat them as wide character.
 
-=item B<discard> => [ "EL", "OSC" ]
+=item B<discard> => [ C<EL>, C<OSC> ]
 
 Specify the list reference of control sequence name to be discarded.
 B<EL> means Erase Line; B<OSC> means Operating System Command, defined
